"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const puppeteer_1 = require("puppeteer");
const highlights_1 = require("./lib/highlights");
const listbooks_1 = require("./lib/listbooks");
const signin_1 = require("./lib/signin");
class PuppeteerGoodreads {
    constructor(opts = {}) {
        this._opts = opts;
    }
    get isAuthenticated() {
        return !!this._user;
    }
    get user() {
        return this._user;
    }
    browser() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            if (!this._browser) {
                this._browser = yield puppeteer_1.launch(this._opts.puppeteer);
            }
            return this._browser;
        });
    }
    signin(username, password) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            if (this.isAuthenticated) {
                throw new Error('"signin" requires no authentication');
            }
            const browser = yield this.browser();
            this._landingPage = yield signin_1.default(browser, username, password);
            this._user = {
                username: username,
                password: password,
            };
        });
    }
    getMyBooks() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            if (!this.isAuthenticated) {
                throw new Error('User must first be logged-in. Use the "signin" function first.');
            }
            return yield listbooks_1.default(this._landingPage);
        });
    }
    getBookHighlights(book) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            if (!this.isAuthenticated) {
                throw new Error('User must first be logged-in. Use the "signin" function first.');
            }
            const browser = yield this.browser();
            return yield highlights_1.default(browser, book);
        });
    }
    close() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const browser = yield this.browser();
            yield browser.close();
            this._browser = null;
            this._user = null;
        });
    }
}
exports.PuppeteerGoodreads = PuppeteerGoodreads;
//# sourceMappingURL=index.js.map