"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
function scrapePaginationUrls(page, baseUrl) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const paginationIndices = yield page.$$eval('.readingNotesPagination a:not([class])', anchors => anchors.map((anchor) => anchor.innerText));
        if (paginationIndices.length === 0) {
            return [];
        }
        const lastPageIndex = parseInt(paginationIndices.slice(-1)[0], 10) || 1;
        return Array.from({ length: lastPageIndex - 1 }, (_x, i) => `${baseUrl}&page=${i + 2}`);
    });
}
exports.scrapePaginationUrls = scrapePaginationUrls;
function scrapeHighlightsFromPageUrl(page) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const highlights = yield page.$$eval('.js-readingNote', highlightsEl => highlightsEl.map(highlightEl => {
            try {
                return {
                    annotationId: highlightEl.getAttribute('data-annotation-pair-id'),
                    bookId: highlightEl.getAttribute('data-book-id'),
                    hasNote: String(highlightEl.getAttribute('data-has-note')) == 'true',
                    locationPercentage: highlightEl.querySelector('.noteHighlightContainer__location').innerText,
                    text: highlightEl.querySelector('.noteHighlightTextContainer__highlightText span:last-of-type').innerText,
                };
            }
            catch (ex) {
                return null;
            }
        }));
        return highlights.filter(n => n);
    });
}
exports.scrapeHighlightsFromPageUrl = scrapeHighlightsFromPageUrl;
function getHighlightsForBook(browser, book) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const page = yield browser.newPage();
        yield page.goto(book.bookUrl);
        const nextPages = yield scrapePaginationUrls(page, book.bookUrl);
        let highlights = yield scrapeHighlightsFromPageUrl(page);
        for (const pageUrl of nextPages) {
            yield page.goto(pageUrl);
            yield page.waitForSelector('#allHighlightsAndNotes');
            const nextHighlights = yield scrapeHighlightsFromPageUrl(page);
            highlights = highlights.concat(nextHighlights);
        }
        return highlights;
    });
}
exports.default = getHighlightsForBook;
//# sourceMappingURL=highlights.js.map